==> nocc-1.9.5.txz: usr/local/www/nocc/lang/ce.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: $
 */
/** Chechen (нохчийн)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Sasan700
 * @author Умар
 */

$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Логин гуш яц';
$err_passwd_empty = 'Пароль гуш яц';
$alt_delete = 'ДӀабаха билгалбина хаамаш';
$alt_delete_one = 'ДӀабаккха хаам';
$alt_new_msg = 'Керла хаамаш';
$alt_reply = 'Жоп ло куьгдена';
$alt_reply_all = 'Жоп ло массарна';
$alt_forward = 'ДӀасхьажор';
$alt_next = 'Кхин дӀа';
$alt_prev = 'ТӀехьа';
$title_next_page = 'ТӀаьхьа йогӀу агӀо';
$title_prev_page = 'Хьалха йоьду агӀо';
$title_next_msg = 'Хьалхарнаш';
$title_prev_msg = 'Хилларш';
$html_theme_label = 'Кечяр:';
$html_welcome = 'Марша догӀийла %1$s чу';
$html_login = 'ЧугӀо';
$html_user_label = 'Декъашхо:';
$html_passwd_label = 'Пароль:';
$html_submit = 'ЧугӀо';
$html_help = 'ГӀо';
$html_server_label = 'Сервер:';
$html_wrong = 'Логин я пароль нийса яц';
$html_retry = 'ЮхагӀорта';
$html_remember = 'Дагалаца гӀирс нисбар';
$html_lang_label = 'Мотт';
$html_msgperpage_label = 'АгӀорахь хаамаш:';
$html_preferences = 'Параметраш';
$html_full_name_label = 'Юьззина цӀе:';
$html_email_address_label = 'Электронан почтан адрес:';
$html_bccself = 'Копи шен';
$html_hide_addresses = 'Хьулде адрес';
$html_outlook_quoting = 'Далийнадош хатIца Outlook';
$html_reply_to = 'Жоп ло';
$html_reply_to_label = 'Жоп ло:';
$html_use_signature = 'Леладе куьг';
$html_signature = 'КуьгтаӀор';
$html_signature_label = 'КуьгтаӀор:';
$html_folder_delete = 'ДӀаяккха';
$html_filter_remove = 'ДӀаяккха';
$html_or = 'я';
$html_move = 'Кхечухьа яккха';
$html_copy = 'Копиян';
$html_page = 'АгӀо';
$html_of = 'чура';
$html_view_header = 'хааман коьртамогӀе хьажа';
$html_remove_header = 'ДӀабаккха хааман корта';
$html_inbox = 'ЧуйогӀурш';
$html_new_msg = 'Язде';
$html_reply = 'Жоп ло';
$html_reply_short = 'Хьаьнга';
$html_reply_all = 'Жоп ло массарна';
$html_forward = 'ДӀасхьажор';
$html_forward_short = 'Да';
$html_delete = 'ДӀаяккха';
$html_new = 'Керланиг';
$html_mark = 'ДӀаяккха';
$html_to_label = 'Хьаьнга:';
$html_cc = 'Копи';
$html_cc_label = 'Копи:';
$html_bcc_label = 'Rss';
$html_send = 'ДӀадахьийта';
$html_cancel = 'Юхаяккха';
$html_no_mail = 'Хаамаш бац';
$html_logout = 'Болх дӀаберзор';
$html_msg = 'Хаам';
$html_msgs = 'Хаам';
$html_priority = 'Приоритет';
$html_priority_label = 'Приоритет:';
$html_lowest = 'Кхин дӀа';
$html_low = 'Лахара';
$html_normal = 'ЛартӀахь';
$html_high = 'Лаккхара';
$html_highest = 'Лаккха';
$html_flagged = 'Билгалйинарш';
$html_spam = 'Спам';
$html_select = 'Харжа';
$html_contact_mail = 'Электронан почтан адрес';
$html_contact_list = 'Контактийн могӀам %1$s';
$html_down_mail = 'Чуяккха';
$html_search = 'Лаха';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/ce.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: $
 */
/** Chechen (нохчийн)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Sasan700
 * @author Умар
 */

$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Логин гуш яц';
$err_passwd_empty = 'Пароль гуш яц';
$alt_delete = 'ДӀабаха билгалбина хаамаш';
$alt_delete_one = 'ДӀабаккха хаам';
$alt_new_msg = 'Керла хаамаш';
$alt_reply = 'Жоп ло куьгдена';
$alt_reply_all = 'Жоп ло массарна';
$alt_forward = 'ДӀасхьажор';
$alt_next = 'Кхин дӀа';
$alt_prev = 'ТӀехьа';
$title_next_page = 'ТӀаьхьа йогӀу агӀо';
$title_prev_page = 'Хьалха йоьду агӀо';
$title_next_msg = 'Хьалхарнаш';
$title_prev_msg = 'Хилларш';
$html_theme_label = 'Кечяр:';
$html_welcome = 'Марша догӀийла %1$s чу';
$html_login = 'ЧугӀо';
$html_user_label = 'Декъашхо:';
$html_passwd_label = 'Пароль:';
$html_submit = 'ЧугӀо';
$html_help = 'ГӀо';
$html_server_label = 'Сервер:';
$html_wrong = 'Логин я пароль нийса яц';
$html_retry = 'ЮхагӀорта';
$html_remember = 'Дагалаца гӀирс нисбар';
$html_lang_label = 'Мотт';
$html_msgperpage_label = 'АгӀорахь хаамаш:';
$html_preferences = 'Параметраш';
$html_full_name_label = 'Юьззина цӀе:';
$html_email_address_label = 'Электронан поштан адрес:';
$html_bccself = 'Копи шен';
$html_hide_addresses = 'Хьулде адрес';
$html_outlook_quoting = 'Далийнадош хатIца Outlook';
$html_reply_to = 'Жоп ло';
$html_reply_to_label = 'Жоп ло:';
$html_use_signature = 'Леладе куьг';
$html_signature = 'КуьгтаӀор';
$html_signature_label = 'КуьгтаӀор:';
$html_folder_delete = 'ДӀаяккха';
$html_filter_remove = 'ДӀаяккха';
$html_or = 'я';
$html_move = 'Кхечухьа яккха';
$html_copy = 'Копиян';
$html_page = 'АгӀо';
$html_of = 'чура';
$html_view_header = 'хааман коьртамогӀе хьажа';
$html_remove_header = 'ДӀабаккха хааман корта';
$html_inbox = 'ЧуйогӀурш';
$html_new_msg = 'Язде';
$html_reply = 'Жоп ло';
$html_reply_short = 'Хьаьнга';
$html_reply_all = 'Жоп ло массарна';
$html_forward = 'ДӀасхьажор';
$html_forward_short = 'Да';
$html_delete = 'ДӀаяккха';
$html_new = 'Керланиг';
$html_mark = 'ДӀаяккха';
$html_to_label = 'Хьаьнга:';
$html_cc = 'Копи';
$html_cc_label = 'Копи:';
$html_bcc_label = 'Rss';
$html_send = 'ДӀадахьийта';
$html_cancel = 'Юхаяккха';
$html_no_mail = 'Хаамаш бац';
$html_logout = 'Болх дӀаберзор';
$html_msg = 'Хаам';
$html_msgs = 'Хаам';
$html_priority = 'Приоритет';
$html_priority_label = 'Приоритет:';
$html_lowest = 'Кхин дӀа';
$html_low = 'Лахара';
$html_normal = 'ЛартӀахь';
$html_high = 'Лаккхара';
$html_highest = 'Лаккха';
$html_flagged = 'Билгалйинарш';
$html_spam = 'Спам';
$html_select = 'Харжа';
$html_contact_mail = 'Электронан поштан адрес';
$html_contact_list = 'Контактийн могӀам %1$s';
$html_down_mail = 'Чуяккха';
$html_search = 'Лахар';
